OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Nesprávné heslo",
    "The new password can not be the same as the previous one" : "Nové heslo nemůže být stejné jako to předchozí",
    "No user supplied" : "Nebyl uveden uživatel",
    "Authentication error" : "Chyba přihlášení",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Zadejte prosím administrátorské heslo pro obnovu, jinak budou všechna data ztracena.",
    "Wrong admin recovery password. Please check the password and try again." : "Chybné administrátorské heslo pro obnovu. Překontrolujte správnost hesla a zkuste to znovu.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Úložiště nepodporuje změnu hesla, ale šifrovací klíč uživatele byl úspěšně aktualizován.",
    "Unable to change password" : "Změna hesla se nezdařila",
    "%s password changed successfully" : "%s heslo bylo změněno vpořádku",
    "Couldn't send reset email. Please contact your administrator." : "Nepodařilo se odeslat email pro změnu hesla. Kontaktujte svého správce systému.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "Instalovat a aktualizovat aplikace pomocí obchodu nebo Sdíleného Cloudového Úložiště",
    "Federated Cloud Sharing" : "Propojené cloudové sdílení",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL používá zastaralou %s verzi (%s). Aktualizujte prosím svůj operační systém, jinak funkce jako %s nemusí spolehlivě pracovat.",
    "A problem occurred, please check your log files (Error: %s)" : "Došlo k chybě, zkontrolujte prosím log (Chyba: %s)",
    "Migration Completed" : "Migrace dokončena",
    "Group already exists." : "Skupina již existuje.",
    "Unable to add group." : "Nelze přidat skupinu.",
    "Unable to delete group." : "Nelze smazat skupinu.",
    "log-level out of allowed range" : "úroveň logování z povoleného rozpětí",
    "Saved" : "Uloženo",
    "test email settings" : "Test nastavení emailu",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Při odesílání emailu nastala chyba. Překontrolujte prosím svá nastavení. (Error: %s)",
    "Email sent" : "Email odeslán",
    "You need to set your user email before being able to send test emails." : "Pro možnost odeslání zkušebních emailů musíte nejprve nastavit svou emailovou adresu.",
    "Couldn't change the email address because the user does not exist" : "Email nemohl být změněn. Uživatel neexistuje",
    "Couldn't change the email address because the token is invalid" : "Email nemohl být změněn. Token je chybný",
    "Invalid mail address" : "Neplatná emailová adresa",
    "A user with that name already exists." : "Uživatel tohoto jména již existuje.",
    "Unable to create user." : "Nelze vytvořit uživatele.",
    "Your %s account was created" : "Účet %s byl vytvořen",
    "Unable to delete user." : "Nelze smazat uživatele.",
    "Forbidden" : "Zakázáno",
    "Invalid user" : "Neplatný uživatel",
    "Unable to change mail address" : "Nelze změnit emailovou adresu",
    "Email has been changed successfully." : "Email byl úspěšně změněn.",
    "An email has been sent to this address for confirmation" : "Byl Vám odeslán email pro potvrzení",
    "No email was sent because you already sent one recently. Please try again later." : "Email byl již nedávno odeslán. Prosím zkuste to znovu později.",
    "Your full name has been changed." : "Vaše celé jméno bylo změněno.",
    "Unable to change full name" : "Nelze změnit celé jméno",
    "%s email address confirm" : "%s potvrzení emailové adresy",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Nepodařilo se odeslat potvrzovací změna e-mailové adresy. Obraťte se na správce.",
    "%s email address changed successfully" : "%s emailová adresa úspěšně změněna",
    "Couldn't send email address change notification mail. Please contact your administrator." : "Nelze odeslat e-mailovou adresu pro oznamování změn poštu. Obraťte se na správce.",
    "Unable to enable/disable user." : "Nelze povolit/zakázat uživatele.",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Česky",
    "Language changed" : "Jazyk byl změněn",
    "Invalid request" : "Neplatný požadavek",
    "Admins can't remove themself from the admin group" : "Správci se nemohou odebrat sami ze skupiny správců",
    "Unknown user" : "Neznámý uživatel",
    "Couldn't remove app." : "Nepodařilo se odebrat aplikaci.",
    "Official" : "Oficiální",
    "Approved" : "Potvrzeno",
    "All" : "Vše",
    "Enabled" : "Povoleno",
    "Not enabled" : "Vypnuto",
    "No apps found for your version" : "Nebyly nalezeny aplikace pro vaši verzi",
    "The app will be downloaded from the app store" : "Aplikace bude stažena z obchodu aplikací",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Oficiální aplikace jsou vyvíjeny komunitou ownCloud. Nabízejí funkce důležité pro ownCloud a jsou připraveny pro nasazení v produkčním prostředí.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Schválené aplikace jsou vyvíjeny důvěryhodnými vývojáři a prošly zběžným bezpečnostním prověřením. Jsou aktivně udržovány v repozitáři s otevřeným kódem a jejich správci je považují za stabilní pro občasné až normální použití.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "U této aplikace nebyla provedena kontrola na bezpečnostní problémy. Aplikace je nová nebo nestabilní. Instalujte pouze na vlastní nebezpečí.",
    "Please wait...." : "Čekejte prosím...",
    "Error while disabling app" : "Chyba při zakazování aplikace",
    "Disable" : "Zakázat",
    "Enable" : "Povolit",
    "Error while enabling app" : "Chyba při povolování aplikace",
    "Error: this app cannot be enabled because it makes the server unstable" : "Chyba: tuto aplikaci nelze zapnout, protože způsobuje nestabilitu serveru",
    "Error: could not disable broken app" : "Chyba: nezdařilo se vypnout rozbitou aplikaci",
    "Error while disabling broken app" : "Chyba při vypínání rozbité aplikace",
    "Updating...." : "Aktualizuji...",
    "Error while updating app" : "Chyba při aktualizaci aplikace",
    "Updated" : "Aktualizováno",
    "Uninstalling ...." : "Probíhá odinstalace ...",
    "Error while uninstalling app" : "Chyba při odinstalaci aplikace",
    "Uninstall" : "Odinstalovat",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikace byla povolena ale je třeba ji aktualizovat. Za 5 sekund budete přesměrování na stránku pro aktualizaci.",
    "App update" : "Aktualizace aplikace",
    "Experimental" : "Experimentální",
    "No apps found for {query}" : "Nebyly nalezeny žádné aplikace pro {query}",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Jste si jisti, že chcete přidat \"{domain}\" mezi důvěryhodné domény?",
    "Add trusted domain" : "Přidat důvěryhodnou doménu",
    "Migration in progress. Please wait until the migration is finished" : "Migrace probíhá. Počkejte prosím než bude dokončena",
    "Migration started …" : "Migrace spuštěna ...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Došlo k chybě. Nahrajte prosím ASCII-kódovaný PEM certifikát.",
    "Valid until {date}" : "Platný do {date}",
    "Delete" : "Smazat",
    "Disconnect" : "Odpojit",
    "Error while loading browser sessions and device tokens" : "Chyba při načítání sezení prohlížeče a tokenů přístroje",
    "Error while creating device token" : "Chyba při vytváření tokenů přístroje",
    "Error while deleting the token" : "Chyba při mazání tokenu",
    "Sending..." : "Odesílání...",
    "Failed to change the email address." : "Chyba při změně emailové adresy.",
    "Email changed successfully." : "Email úspěšně změněn",
    "An error occurred: {message}" : "Nastala chyba: {message}",
    "Select a profile picture" : "Vyberte profilový obrázek",
    "Very weak password" : "Velmi slabé heslo",
    "Weak password" : "Slabé heslo",
    "So-so password" : "Středně silné heslo",
    "Good password" : "Dobré heslo",
    "Strong password" : "Silné heslo",
    "Groups" : "Skupiny",
    "Unable to delete {objName}" : "Nelze smazat {objName}",
    "Error creating group: {message}" : "Chyba vytvoření skupiny: {message}",
    "A valid group name must be provided" : "Musíte zadat platný název skupiny",
    "deleted {groupName}" : "smazána {groupName}",
    "undo" : "vrátit zpět",
    "never" : "nikdy",
    "deleted {userName}" : "smazán {userName}",
    "add group" : "přidat skupinu",
    "Invalid quota value \"{val}\"" : "Neplatná hodnota kvóty \"{val}\"",
    "enabled" : "povoleno",
    "disabled" : "zakázáno",
    "User {uid} has been {state}!" : "Uživatel {uid} byl {state}!",
    "no group" : "není ve skupině",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Změna hesla bude mít za následek ztrátu dat, protože jejich obnova není pro tohoto uživatele dostupná.",
    "Password successfully changed" : "Heslo bylo úspěšně změněno",
    "A valid username must be provided" : "Musíte zadat platné uživatelské jméno",
    "Error creating user: {message}" : "Chyba vytvoření uživatele: {message}",
    "A valid password must be provided" : "Musíte zadat platné heslo",
    "A valid email must be provided" : "Musíte zadat platný email",
    "Use the following link to confirm your changes to the email address: {link}" : "Použijte tento odkaz pro potvrzení změn na emailové adrese: {link}",
    "Email address changed to {mailAddress} successfully." : "Emailová adresa {mailAddress} úspěšně změněna.",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Ahoj,<br><br>toto je oznámení o nově vytvořeném %s účtu.<br><br>Uživatelské jméno: %s<br>Přihlásit se dá zde: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Ať slouží!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Ahoj,\n\ntoto je oznámení o nově vytvořeném %s účtu.\n\nUživatelské jméno: %s\nPřihlásit se dá zde: %s\n",
    "User documentation" : "Dokumentace uživatele",
    "Administrator documentation" : "Dokumentace administrátora",
    "Online documentation" : "Online dokumentace",
    "Forum" : "Fórum",
    "Issue tracker" : "Seznam chyb",
    "Commercial support" : "Placená podpora",
    "Apps Management" : "Správa aplikace",
    "Developer documentation" : "Vývojářská dokumentace",
    "by %s" : "%s",
    "%s-licensed" : "%s-licencováno",
    "Documentation:" : "Dokumentace:",
    "Admin documentation" : "Dokumentace pro administrátory",
    "Visit website" : "Navštívit webovou stránku",
    "Report a bug" : "Nahlásit chybu",
    "Show description …" : "Zobrazit popis ...",
    "Hide description …" : "Skrýt popis ...",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Tato aplikace nemá přiřazenou nejnižší verzi ownCloud. Toto povede k chybě v ownCloud 11 a vyšším.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Tato aplikace nemá přiřazenou nejvyšší verzi ownCloud. Toto povede k chybě v ownCloud 11 a vyšším.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Tuto aplikaci nelze nainstalovat, protože nejsou splněny následující závislosti:",
    "Enable only for specific groups" : "Povolit pouze pro vybrané skupiny",
    "Uninstall App" : "Odinstalovat aplikaci",
    "Show enabled apps" : "Zobrazit povolené aplikace",
    "Show disabled apps" : "Zobrazit zakázané aplikace",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Poslední cron proběhl: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Poslední cron proběhl: %s. Vypadá to, že něco není v pořádku.",
    "Cron was not executed yet!" : "Cron ještě nebyl spuštěn!",
    "Open documentation" : "Otevřít dokumentaci",
    "Execute one task with each page loaded" : "Spustit jednu úlohu s každým načtením stránky",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php je registrován u služby webcron, aby volal cron.php jednou za 15 minut přes http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Použít systémovou službu cron pro volání cron.php každých 15 minut.",
    "SSL Root Certificates" : "Kořenové certifikáty SSL",
    "Common Name" : "Common Name",
    "Valid until" : "Platný do",
    "Issued By" : "Vydal",
    "Valid until %s" : "Platný do %s",
    "Import root certificate" : "Import kořenového certifikátu",
    "Server-side encryption" : "Šifrování na serveru",
    "Enable server-side encryption" : "Povolit šifrování na straně serveru",
    "Please read carefully before activating server-side encryption: " : "Pročtěte prosím důkladně před aktivací šifrování dat na serveru:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Poté co je zapnuto šifrování, jsou od toho bodu všechny nahrávané soubory šifrovány serverem. Vypnout šifrování bude možné pouze později, až bude šifrovací modul tuto možnost podporovat a po splnění všech nutných podmínek (tzn. nastavení klíčů pro obnovení).",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Samotné šifrování nezajistí bezpečnost systému. Projděte si dokumentaci aplikace ownCloud pro více informací o tom jak šifrovací aplikace funguje a jejím správném použití.",
    "Be aware that encryption always increases the file size." : "Mějte na paměti, že šifrování vždy navýší velikost souboru.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Je vždy dobré vytvářet pravidelné zálohy svých dat, v případě zapnutého šifrování také zajistěte zálohu šifrovacích klíčů společně se zálohou dat.",
    "This is the final warning: Do you really want to enable encryption?" : "Toto je poslední varování: Opravdu si přejete zapnout šifrování?",
    "Enable encryption" : "Povolit šifrování",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Není načten žádný šifrovací modul, povolte ho prosím v menu aplikací.",
    "Select default encryption module:" : "Vybrat výchozí šifrovací modul:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Musíte přenést své šifrovací klíče ze staré verze šifrování (ownCloud <= 8.0) na novou. Povolte prosím \"Default encryption module\" a spusťte příkaz 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Musíte přenést své šifrovací klíče ze staré verze šifrování (ownCloud <= 8.0) na novou.",
    "Start migration" : "Spustit migraci",
    "Sharing" : "Sdílení",
    "Allow apps to use the Share API" : "Povolit aplikacím používat API sdílení",
    "Allow users to share via link" : "Povolit uživatelům sdílení pomocí odkazů",
    "Allow public uploads" : "Povolit veřejné nahrávání souborů",
    "Enforce password protection" : "Vynutit ochranu heslem",
    "Set default expiration date" : "Nastavit výchozí datum vypršení platnosti",
    "Allow users to send mail notification for shared files" : "Povolit uživatelům odesílat emailová upozornění pro sdílené soubory",
    "Allow users to share file via social media" : "Povolit uživatelům sdílení pomocí sociálních médií",
    "Expire after " : "Vyprší po",
    "days" : "dnech",
    "Enforce expiration date" : "Vynutit datum vypršení",
    "Allow resharing" : "Povolit znovu-sdílení",
    "Allow sharing with groups" : "Povolit sdílení se skupinami",
    "Restrict users to only share with users in their groups" : "Povolit sdílení pouze mezi uživateli v rámci skupiny",
    "Allow users to send mail notification for shared files to other users" : "Povolit uživatelům odesílat emailová upozornění na sdílené soubory ostatním uživatelům",
    "Exclude groups from sharing" : "Vyjmout skupiny ze sdílení",
    "These groups will still be able to receive shares, but not to initiate them." : "Těmto skupinám bude stále možno sdílet, nemohou ale sami sdílet ostatním.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Povolit automatické vyplňování v dialogu sdílení. Pokud je toto vypnuto, je třeba ručně vyplňovat celé uživatelské jméno.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Vše (fatální problémy, chyby, varování, informační, ladící)",
    "Info, warnings, errors and fatal issues" : "Informace, varování, chyby a fatální problémy",
    "Warnings, errors and fatal issues" : "Varování, chyby a fatální problémy",
    "Errors and fatal issues" : "Chyby a fatální problémy",
    "Fatal issues only" : "Pouze fatální problémy",
    "Log" : "Záznam",
    "What to log" : "Co se má logovat",
    "Download logfile (%s)" : "Stáhnout soubor logu (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Soubor logu je větší než 100 MB. Jeho stažení zabere nějaký čas!",
    "None" : "Žádné",
    "Login" : "Přihlásit",
    "Plain" : "Čistý text",
    "NT LAN Manager" : "Správce NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Emailový server",
    "This is used for sending out notifications." : "Toto se používá pro odesílání upozornění.",
    "Send mode" : "Mód odesílání",
    "Encryption" : "Šifrování",
    "From address" : "Adresa odesílatele",
    "mail" : "email",
    "Authentication method" : "Metoda ověření",
    "Authentication required" : "Vyžadováno ověření",
    "Server address" : "Adresa serveru",
    "Port" : "Port",
    "Credentials" : "Přihlašovací údaje",
    "SMTP Username" : "SMTP uživatelské jméno ",
    "SMTP Password" : "SMTP heslo",
    "Store credentials" : "Ukládat přihlašovací údaje",
    "Test email settings" : "Test nastavení emailu",
    "Send email" : "Odeslat email",
    "Security & setup warnings" : "Upozornění zabezpečení a nastavení",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php není nejspíše správně nastaveno pro dotazování na proměnné hodnoty systému. Test s getenv(\"PATH\") vrací pouze prázdnou odpověď.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Zkontrolujte prosím konfiguraci php podle <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">instalační dokumentace ↗</a>, hlavně při použití php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfigurace je nastavena pouze pro čtení. Toto znemožňuje některá nastavení přes webové rozhraní. Dále musí být pro každou změnu povolen zápis do konfiguračního souboru ručně.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je patrně nastaveno tak, aby odstraňovalo bloky komentářů. Toto bude mít za následek nedostupnost množství hlavních aplikací.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Toto je pravděpodobně způsobeno aplikacemi pro urychlení načítání jako jsou Zend OPcache nebo eAccelerator.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vaše databáze neběží s úrovní izolace transakcí \"READ COMMITED\". Toto může způsobit problémy při paralelním spouštění více akcí současně.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "Je nainstalován %1$s nižší verze než %2$s, z důvodu lepší stability a výkonu doporučujeme aktualizovat na novější verzi %1$s.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Schází PHP modul 'fileinfo'. Doporučujeme jej povolit pro nejlepší výsledky detekce typů MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Transakční uzamykání souborů je vypnuto, což může vést k problémům s \"race\" podmínkami. Pro zabránění těmto problémům povolte 'filelocking.enabled' v souboru config.php. Více informací lze nalézt v <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentaci ↗</a>.",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Blokování transakčních souborů by mělo být nakonfigurováno tak, aby používaly blokování založené na paměti, nikoliv blokování založené na pomalé databázi. Další informace naleznete v <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\"> dokumentaci ↗ </a>.",
    "System locale can not be set to a one which supports UTF-8." : "Není možné nastavit znakovou sadu, která podporuje UTF-8.",
    "This means that there might be problems with certain characters in file names." : "To znamená, že se mohou vyskytnout problémy s určitými znaky v názvech souborů.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Velmi doporučujeme nainstalovat požadované balíčky do systému, pro podporu jednoho z následujících národních prostředí: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Instalace mimo kořenový adresář domény a používání systémového příkazu cron může způsobit problém s generováním správné URL. Pro zabránění těmto chybám nastavte prosím správnou cestu ve svém config.php souboru v hodnotě \"overwrite.cli.url\" (Je doporučena tato: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Je použita databáze SQLite. Pro větší instalace doporučujeme přejít na robustnější databázi.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Obzvláště při používání klientské aplikace pro synchronizaci s desktopem není SQLite doporučeno.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Pro migraci na jinou databázi použijte v příkazovém řádku nástroj: 'occ db:convert-type' nebo nahlédněte do <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentace ↗</a>.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Doporučujeme povolit systémový cron, protože jakýkoli jiný cron má možné dopady na výkon a spolehlivost.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Nebylo možné spustit službu cron v CLI. Došlo k následujícím technickým chybám:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Prosím překontrolujte <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">instalační pokyny ↗</a> a zkontrolujte jakékoliv chyby a varování v <a href=\"#log-section\">logu</a>.",
    "All checks passed." : "Všechny testy byly úspěšné.",
    "System Status" : "Systém status",
    "Tips & tricks" : "Tipy a triky",
    "How to do backups" : "Jak vytvářet zálohy",
    "Advanced monitoring" : "Pokročilé monitorování",
    "Performance tuning" : "Ladění výkonu",
    "Improving the config.php" : "Vylepšení souboru config.php",
    "Theming" : "Vzhledy",
    "Hardening and security guidance" : "Průvodce vylepšením bezpečnosti",
    "Get the apps to sync your files" : "Získat aplikace pro synchronizaci vašich souborů",
    "Desktop client" : "Aplikace pro počítač",
    "Android app" : "Aplikace pro Android",
    "iOS app" : "iOS aplikace",
    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Chcete-li podpořit tento projekt\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spojit s vývojáři</a>\n\t\t\tnebo\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">šířit projekt</a>!",
    "Show First Run Wizard again" : "Znovu zobrazit průvodce prvním spuštěním",
    "Profile picture" : "Profilový obrázek",
    "Upload new" : "Nahrát nový",
    "Select from Files" : "Vybrat ze Souborů",
    "Remove image" : "Odebrat obrázek",
    "png or jpg, max. 20 MB" : "png nebo jpg, max. 20 MB",
    "Picture provided by original account" : "Obrázek je poskytován původním účtem",
    "Cancel" : "Zrušit",
    "Choose as profile picture" : "Vybrat jako profilový obrázek",
    "Full name" : "Celé jméno",
    "No display name set" : "Jméno pro zobrazení nenastaveno",
    "Email" : "Email",
    "Your email address" : "Vaše emailová adresa",
    "Change email" : "Změna emailu",
    "Set email" : "Nastavení emailu",
    "For password recovery and notifications" : "Pro obnovení hesla a upozornění",
    "No email address set" : "Emailová adresa není nastavena",
    "You are member of the following groups:" : "Patříte do následujících skupin:",
    "Password" : "Heslo",
    "Unable to change your password" : "Změna vašeho hesla se nezdařila",
    "Current password" : "Současné heslo",
    "New password" : "Nové heslo",
    "Change password" : "Změnit heslo",
    "Language" : "Jazyk",
    "Help translate" : "Pomoci s překladem",
    "Unlimited" : "Neomezeně",
    "You are using %s of %s" : "Používáte %s z %s",
    "You are using %s of %s (%s %%)" : "Používáte %s z %s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Vyvíjeno {communityopen}komunitou ownCloud{linkclose}, {githubopen}zdrojový kód{linkclose} je licencován pod {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Sessions" : "Sezení",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Toto jsou klienti aktuálně přihlášení do této instance ownCloud přes web, počítač, či telefon.",
    "Browser" : "Prohlížeč",
    "Most recent activity" : "Nejnovější aktivity",
    "App passwords" : "Hesla aplikací",
    "You've linked these apps." : "Připojili jste tyto aplikace.",
    "Name" : "Název",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Heslo aplikace je přihlašovací údaj umožňující aplikaci nebo přístroji přístup k %s účtu.",
    "App name" : "Jméno aplikace",
    "Create new app password" : "Vytvořit nové heslo aplikace",
    "Use the credentials below to configure your app or device." : "Použijte níže vypsané přihlašovací údaje k nastavení aplikace nebo přístroje.",
    "Username" : "Uživatelské jméno",
    "Done" : "Dokončeno",
    "Version" : "Verze",
    "Personal" : "Osobní",
    "Admin" : "Administrace",
    "Error" : "Chyba",
    "No panels for this section." : "Žádné panely pro tuto sekci.",
    "Show enabled/disabled option" : "Zobrazení možnosti pro povolení/zakázání",
    "Show storage location" : "Cesta k datům",
    "Show last log in" : "Poslední přihlášení",
    "Show user backend" : "Zobrazit uživatelskou podpůrnou vrstvu",
    "Send email to new user" : "Poslat email novému uživateli",
    "Show email address" : "Emailová adresa",
    "E-Mail" : "Email",
    "Create" : "Vytvořit",
    "Admin Recovery Password" : "Heslo obnovy správce",
    "Enter the recovery password in order to recover the users files during password change" : "Zadejte heslo obnovy pro obnovení souborů uživatele při změně hesla",
    "Add Group" : "Přidat skupinu",
    "Group" : "Skupina",
    "Everyone" : "Všichni",
    "Admins" : "Administrátoři",
    "Default Quota" : "Výchozí kvóta",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Zvolte prosím kvótu pro úložiště (např. \"512 MB\" nebo \"12 GB\")",
    "Other" : "Jiný",
    "Full Name" : "Celé jméno",
    "Group Admin for" : "Správce skupiny ",
    "Quota" : "Kvóta",
    "Storage Location" : "Umístění úložiště",
    "User Backend" : "Uživatelská podpůrná vrstva",
    "Last Login" : "Poslední přihlášení",
    "change full name" : "změnit celé jméno",
    "set new password" : "nastavit nové heslo",
    "change email address" : "změnit emailovou adresu",
    "Default" : "Výchozí",
    "Change" : "Změnit",
    "Share" : "Sdílet",
    "White-listed Domains" : "Seznam povolených domén",
    "Domain" : "Doména",
    "Add Domain" : "Přidat doménu",
    "Email address" : "Emailová adresa",
    "Invalid email address" : "Chybná emailová adresa",
    "Restrict enumeration to group members" : "Omezení výčtu na členy skupiny",
    "Extra field to display in autocomplete results" : "Zobrazit další pole pro automatické dokončování",
    "No Domains." : "Bez domén.",
    "Are you sure you want to remove this domain?" : "Chcete odstranit tuto doménu?",
    "Add" : "Přidat",
    "Empty app name is not allowed." : "Prázdné jméno aplikace není dovoleno.",
    "Email changed successfully for {user}." : "Email pro {user} byl změněn.",
    "You are not a member of any groups." : "Nejste členem žádné skupiny."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
